#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# parce documentation build configuration file, created by
# sphinx-quickstart on Fri Dec 20 19:53:27 2019.
#
# This file is execfile()d with the current directory set to its
# containing dir.
#
# Note that not all possible configuration values are present in this
# autogenerated file.
#
# All configuration values have a default; values that are commented out
# serve to show the default.

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
import os
import sys
sys.path.insert(0, os.path.abspath('../..'))
import parce.pkginfo


### begin custom Lexicon documenter
from sphinx.ext.autodoc import ClassLevelDocumenter
from sphinx.util.inspect import getdoc
from sphinx.util.docstrings import prepare_docstring
class LexiconDocumenter(ClassLevelDocumenter):
    objtype = 'lexicon'
    directivetype = 'attribute'
    priority = 100

    @classmethod
    def can_document_member(cls, member, membername, isattr, parent):
        return isinstance(member, parce.lexicon_.Lexicon)

    def get_doc(self, encoding=None, ignore=1):
        docstring = getdoc(self.object.lexicon.rules_func, self.get_attr,
                           self.env.config.autodoc_inherit_docstrings)
        return [prepare_docstring(docstring, ignore)] if docstring else []

    def document_members(self, all_members = False):
        pass

def setup(app):
    app.add_autodocumenter(LexiconDocumenter)
### end custom Lexicon documenter


# -- General configuration ------------------------------------------------

# If your documentation needs a minimal Sphinx version, state it here.
#
# needs_sphinx = '1.0'

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    'sphinx.ext.autodoc',
#    'sphinx.ext.doctest',
#    'sphinx.ext.coverage',
    'sphinx.ext.viewcode',
    'sphinx.ext.intersphinx',
]

# autodoc
autodoc_member_order = 'bysource'
autodoc_default_options = {
    'member-order': 'bysource',
}

# If true, the current module name will be prepended to all description
# unit titles (such as .. function::).
add_module_names = False

# intersphinx
intersphinx_mapping = {'python': ('https://docs.python.org/3', None)}

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# The suffix(es) of source filenames.
# You can specify multiple suffix as a list of string:
#
# source_suffix = ['.rst', '.md']
source_suffix = '.rst'

# The master toctree document.
master_doc = 'index'

# General information about the project.
project = parce.pkginfo.name
copyright = parce.pkginfo.copyright_year + ', ' + parce.pkginfo.maintainer
author = parce.pkginfo.maintainer

# The version info for the project you're documenting, acts as replacement for
# |version| and |release|, also used in various other places throughout the
# built documents.
#
# The short X.Y version.
version = '.'.join(map(format, parce.version))
# The full version, including alpha/beta/rc tags.
release = parce.pkginfo.version_string

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#
# This is also used if you do content translation via gettext catalogs.
# Usually you set "language" from the command line for these cases.
language = None

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This patterns also effect to html_static_path and html_extra_path
exclude_patterns = []

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = 'sphinx'

# If true, `todo` and `todoList` produce output, else they produce nothing.
todo_include_todos = False


# -- Options for HTML output ----------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
#html_theme = 'alabaster'
html_theme = 'alabaster'

# Theme options are theme-specific and customize the look and feel of a theme
# further.  For a list of options available for each theme, see the
# documentation.
#
html_theme_options = {
    'logo': 'parce-logo.png',
    'fixed_sidebar': 'true',
    'github_user': 'wbsoft',
    'github_repo': 'parce',
#    'show_related': 'true',
    'show_relbar_bottom': 'true',
    'description': parce.pkginfo.description,
    'extra_nav_links': {
        'parce@Github': 'https://github.com/wbsoft/parce',
        'parce@PyPi': 'https://pypi.org/project/parce',
        'parce for Qt': 'https://parce.info/parceqt',
    },
}

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']

# Custom sidebar templates, must be a dictionary that maps document names
# to template names.
#
# This is required for the alabaster theme
# refs: http://alabaster.readthedocs.io/en/latest/installation.html#sidebars
html_sidebars = {
    '**': [
        'about.html',
        'navigation.html',
        'relations.html',  # needs 'show_related': True theme option to display
        'searchbox.html',
    ]
}


# -- Options for HTMLHelp output ------------------------------------------

# Output file base name for HTML help builder.
htmlhelp_basename = 'parcedoc'


# -- Options for LaTeX output ---------------------------------------------

latex_elements = {
    # The paper size ('letterpaper' or 'a4paper').
    #
    # 'papersize': 'letterpaper',

    # The font size ('10pt', '11pt' or '12pt').
    #
    # 'pointsize': '10pt',

    # Additional stuff for the LaTeX preamble.
    #
    # 'preamble': '',

    # Latex figure (float) alignment
    #
    # 'figure_align': 'htbp',
}

# Grouping the document tree into LaTeX files. List of tuples
# (source start file, target name, title,
#  author, documentclass [howto, manual, or own class]).
latex_documents = [
    (master_doc, 'parce.tex', 'parce Documentation',
     'Wilbert Berendsen', 'manual'),
]


# -- Options for manual page output ---------------------------------------

# One entry per manual page. List of tuples
# (source start file, name, description, authors, manual section).
man_pages = [
    (master_doc, 'parce', 'parce Documentation',
     [author], 1)
]


# -- Options for Texinfo output -------------------------------------------

# Grouping the document tree into Texinfo files. List of tuples
# (source start file, target name, title, author,
#  dir menu entry, description, category)
texinfo_documents = [
    (master_doc, 'parce', 'parce Documentation',
     author, 'parce', 'One line description of project.',
     'Miscellaneous'),
]



